==> blender-2.57b.tar.gz: blender-2.57b/source/blender/editors/include/ED_curve.h <==
/*
 * $Id: ED_curve.h 36278 2011-04-21 17:25:58Z campbellbarton $
 *
 * ***** BEGIN GPL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. 
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The Original Code is Copyright (C) 2009 Blender Foundation.
 * All rights reserved.
 *
 * 
 * Contributor(s): Blender Foundation
 *
 * ***** END GPL LICENSE BLOCK *****
 */

/** \file ED_curve.h
 *  \ingroup editors
 */

#ifndef ED_CURVE_H
#define ED_CURVE_H

struct Base;
struct bContext;
struct Nurb;
struct Object;
struct Scene;
struct Text;
struct View3D;
struct wmOperator;
struct wmKeyConfig;
struct Curve;
struct EditNurb;
struct BezTriple;
struct BPoint;

/* curve_ops.c */
void	ED_operatortypes_curve(void);
void	ED_keymap_curve	(struct wmKeyConfig *keyconf);

/* editcurve.c */
void CU_deselect_all(struct Object *obedit);
void CU_select_all(struct Object *obedit);
void CU_select_swap(struct Object *obedit);


void	undo_push_curve	(struct bContext *C, const char *name);
ListBase *curve_get_editcurve(struct Object *ob);

void	load_editNurb	(struct Object *obedit);
void	make_editNurb	(struct Object *obedit);
void	free_editNurb	(struct Object *obedit);

void	free_curve_editNurb	(struct Curve *cu);

int 	mouse_nurb		(struct bContext *C, const short mval[2], int extend);

struct Nurb *add_nurbs_primitive(struct bContext *C, float mat[4][4], int type, int newob);

int		isNurbsel		(struct Nurb *nu);

int		join_curve_exec	(struct bContext *C, struct wmOperator *op);

/* editfont.h */
void	undo_push_font	(struct bContext *C, const char *name);
void	make_editText	(struct Object *obedit);
void	load_editText	(struct Object *obedit);
void	free_editText	(struct Object *obedit);

void	ED_text_to_object(struct bContext *C, struct Text *text, int split_lines);

int CU_select_nth(struct Object *obedit, int nth);
ListBase *ED_curve_editnurbs(struct Curve *cu);

void ED_curve_beztcpy(struct EditNurb *editnurb, struct BezTriple *dst, struct BezTriple *src, int count);
void ED_curve_bpcpy(struct EditNurb *editnurb, struct BPoint *dst, struct BPoint *src, int count);

int ED_curve_updateAnimPaths(struct Object *obedit);

/* debug only */
void printknots(struct Object *obedit);

#endif /* ED_CURVE_H */

==> blender_2.59.orig.tar.gz: blender-2.59/source/blender/editors/include/ED_curve.h <==
/*
 * $Id: ED_curve.h 38111 2011-07-05 08:57:11Z blendix $
 *
 * ***** BEGIN GPL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. 
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The Original Code is Copyright (C) 2009 Blender Foundation.
 * All rights reserved.
 *
 * 
 * Contributor(s): Blender Foundation
 *
 * ***** END GPL LICENSE BLOCK *****
 */

/** \file ED_curve.h
 *  \ingroup editors
 */

#ifndef ED_CURVE_H
#define ED_CURVE_H

struct Base;
struct bContext;
struct Nurb;
struct Object;
struct Scene;
struct Text;
struct View3D;
struct wmOperator;
struct wmKeyConfig;
struct Curve;
struct EditNurb;
struct BezTriple;
struct BPoint;

/* curve_ops.c */
void	ED_operatortypes_curve(void);
void	ED_keymap_curve	(struct wmKeyConfig *keyconf);

/* editcurve.c */
void CU_deselect_all(struct Object *obedit);
void CU_select_all(struct Object *obedit);
void CU_select_swap(struct Object *obedit);


void	undo_push_curve	(struct bContext *C, const char *name);
ListBase *curve_get_editcurve(struct Object *ob);

void	load_editNurb	(struct Object *obedit);
void	make_editNurb	(struct Object *obedit);
void	free_editNurb	(struct Object *obedit);

void	free_curve_editNurb	(struct Curve *cu);

int 	mouse_nurb		(struct bContext *C, const int mval[2], int extend);

struct Nurb *add_nurbs_primitive(struct bContext *C, float mat[4][4], int type, int newob);

int		isNurbsel		(struct Nurb *nu);
void	ED_nurb_set_spline_type(struct Nurb *nu, int type);

int		join_curve_exec	(struct bContext *C, struct wmOperator *op);

/* editfont.h */
void	undo_push_font	(struct bContext *C, const char *name);
void	make_editText	(struct Object *obedit);
void	load_editText	(struct Object *obedit);
void	free_editText	(struct Object *obedit);

void	ED_text_to_object(struct bContext *C, struct Text *text, int split_lines);

int CU_select_nth(struct Object *obedit, int nth);
ListBase *ED_curve_editnurbs(struct Curve *cu);

void ED_curve_beztcpy(struct EditNurb *editnurb, struct BezTriple *dst, struct BezTriple *src, int count);
void ED_curve_bpcpy(struct EditNurb *editnurb, struct BPoint *dst, struct BPoint *src, int count);

int ED_curve_updateAnimPaths(struct Object *obedit);

/* debug only */
void printknots(struct Object *obedit);

#endif /* ED_CURVE_H */
